@@ -2,6 +2,11 @@ use crate::data::Readout;
 use colored::Colorize;
 use libmacchina::traits::ReadoutError;
 
+#[cfg(windows)]
+fn activate_virtual_terminal() {
+    colored::control::set_virtual_terminal(true).expect("Could not activate virtual terminal.");
+}
+
 fn split_failed_items<'a>(
     failed_items: &'a [&Readout],
 ) -> (Vec<&'a Readout<'a>>, Vec<&'a Readout<'a>>) {
@@ -61,21 +66,12 @@ fn print_warnings<'a>(warn_items: &[&'a Readout<'a>], total_failed_items: usize)
     }
 }
 
-#[cfg(windows)]
-fn activate_virtual_terminal() {
-    colored::control::set_virtual_terminal(true).expect("Could not activate virtual terminal.");
-}
-
-#[cfg(not(windows))]
-fn activate_virtual_terminal() {}
-
 pub(crate) fn print_doctor(data: &[Readout]) {
     let failed_items: Vec<_> = data.iter().filter(|p| p.1.is_err()).collect();
     let (err_items, warn_items) = split_failed_items(&failed_items);
 
-    if cfg!(windows) {
-        activate_virtual_terminal();
-    }
+    #[cfg(windows)]
+    activate_virtual_terminal();
 
     println!(
         "Let's check your system for {}... Here's a summary:\n",
